==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Allir efnisflokkar");
define("_NOCOMMENTS","Engar athugasemdir");
define("_UCOMMENT","Athugasemd");
define("_REVIEWS","umsagnir");
define("_SEARCHUSERS","Leita  notendagrunni");
define("_SEARCHSECTIONS","Leita  greinasafni");
define("_SEARCHREVIEWS","Leita  umsgnum");
define("_SEARCHIN","Leita ");
define("_ARTICLES","greinar");
define("_ALLAUTHORS","Allir hfundar");
define("_ALL","Allt");
define("_WEEK","vika");
define("_WEEKS","vikur");
define("_MONTH","mnuur");
define("_MONTHS","mnuir");
define("_SEARCHON","Leita :");
define("_SSTORIES","sgur/frttir");
define("_SSECTIONS","greinar");
define("_SUSERS","notendur");
define("_NOMATCHES","Ekkert fannst");
define("_PREVMATCHES","fyrri niurstur");
define("_NEXTMATCHES","nstu niurstur");
define("_INSECTION","Grein  svinu");
define("_NONAME","Ekkert nafn skr");
define("_SCOMMENTS","athugasemdir");
define("_SEARCHRESULTS","Leitarniurstur");
define("_CONTRIBUTEDBY","Sent inn af");
define("_UCOMMENTS","Athugasemdir");
define("_MATCHTITLE","Fannst  titli");
define("_MATCHTEXT","Fannst  texta");
define("_MATCHBOTH","Fannst  titli og texta");
define("_SREPLY","svar");
define("_SREPLIES","svr");
define("_ATTACHART","Tengt grein");
define("_PAGES","Sur");
define("_REVIEWSCORE","Einkunn");
define("_PAGE","Sa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Allir efnisflokkar");
define("_NOCOMMENTS","Engar athugasemdir");
define("_UCOMMENT","Athugasemd");
define("_REVIEWS","umsagnir");
define("_SEARCHUSERS","Leita  notendagrunni");
define("_SEARCHSECTIONS","Leita  greinasafni");
define("_SEARCHREVIEWS","Leita  umsgnum");
define("_SEARCHIN","Leita ");
define("_ARTICLES","greinar");
define("_ALLAUTHORS","Allir hfundar");
define("_ALL","Allt");
define("_WEEK","vika");
define("_WEEKS","vikur");
define("_MONTH","mnuur");
define("_MONTHS","mnuir");
define("_SEARCHON","Leita :");
define("_SSTORIES","sgur/frttir");
define("_SSECTIONS","greinar");
define("_SUSERS","notendur");
define("_NOMATCHES","Ekkert fannst");
define("_PREVMATCHES","fyrri niurstur");
define("_NEXTMATCHES","nstu niurstur");
define("_INSECTION","Grein  svinu");
define("_NONAME","Ekkert nafn skr");
define("_SCOMMENTS","athugasemdir");
define("_SEARCHRESULTS","Leitarniurstur");
define("_CONTRIBUTEDBY","Sent inn af");
define("_UCOMMENTS","Athugasemdir");
define("_MATCHTITLE","Fannst  titli");
define("_MATCHTEXT","Fannst  texta");
define("_MATCHBOTH","Fannst  titli og texta");
define("_SREPLY","svar");
define("_SREPLIES","svr");
define("_ATTACHART","Tengt grein");
define("_PAGES","Sur");
define("_REVIEWSCORE","Einkunn");
define("_PAGE","Sa");

?>
